@@ -2,13 +2,20 @@ import time
 from datetime import datetime
 
 class Timer:
-    
+
+    def count_down(s):
+        s = int(s)
+        for i in range(s):
+            print(s - i)
+            time.sleep(s)
+        print(0)    
+
     def sleep(s):
         time.sleep(s)
-        return s 
+        print(s) 
 
     def now():
-        return datetime.now()
+        print(datetime.now())
 
     def count_function(function):
         time_start = datetime.now()
@@ -16,6 +23,5 @@ class Timer:
         time_end = datetime.now()
         time_used = str(time_end - time_start)
         function_name = function.__name__ 
-        return '%s(): %s' % (function_name, time_used)
-
+        print('%s(): %s' % (function_name, time_used))
 
